import { Configuration, DiskDriver } from 'typefs-registry';
/**
 * Storage access
 */
export declare class Storage {
    private static instance;
    protected conf: Configuration | undefined;
    protected drivers: Record<string, CallableFunction>;
    static getInstance(): Storage;
    /**
     * Configure storage
     *
     * @param {Configuration} c - config JSON
     */
    static set config(c: Configuration);
    /**
     * Access disk
     *
     * @param {string|undefined} disk to select. leaving undefined will result in
     * default disk being selected
     * @returns {DiskDriver} common interface for all drivers
     */
    static disk(disk?: string): DiskDriver;
    /**
     * Registers a driver to the storage manager.
     *
     * Caution: this will override existing drivers
     *
     * @param {string} name of the driver eg, file, s3, http etc...
     * @param {CallableFunction} driver (DiskConfiguration) -> TDiskDriver
     *
     * (configuration: DiskConfiguration) => new MyDriver(configuration as MyDisk),
     */
    static registerDriver(name: string, driver: CallableFunction): void;
}
