"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Storage = void 0;
var drivers_1 = require("./drivers");
/**
 * Storage access
 */
var Storage = /** @class */ (function () {
    function Storage() {
        this.drivers = {
            file: function (configuration) { return new drivers_1.FileDriver(configuration); },
        };
    }
    Storage.getInstance = function () {
        if (this.instance) {
            return this.instance;
        }
        this.instance = new Storage();
        return this.instance;
    };
    Object.defineProperty(Storage, "config", {
        /**
         * Configure storage
         *
         * @param {Configuration} c - config JSON
         */
        set: function (c) {
            var inst = Storage.getInstance();
            inst.conf = c;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Access disk
     *
     * @param {string|undefined} disk to select. leaving undefined will result in
     * default disk being selected
     * @returns {DiskDriver} common interface for all drivers
     */
    Storage.disk = function (disk) {
        var inst = Storage.getInstance();
        if (inst.conf === undefined) {
            throw new Error('Missing configuration');
        }
        var dkey = disk === undefined ? inst.conf.default : disk;
        var configuration = inst.conf.disks[dkey];
        var driver = configuration.driver;
        if (Object.keys(inst.drivers).includes(driver)) {
            return inst.drivers[driver](configuration);
        }
        throw new Error("Disk driver \"".concat(driver, "\" for disk \"").concat(disk, "\" is not found"));
    };
    /**
     * Registers a driver to the storage manager.
     *
     * Caution: this will override existing drivers
     *
     * @param {string} name of the driver eg, file, s3, http etc...
     * @param {CallableFunction} driver (DiskConfiguration) -> TDiskDriver
     *
     * (configuration: DiskConfiguration) => new MyDriver(configuration as MyDisk),
     */
    Storage.registerDriver = function (name, driver) {
        var inst = Storage.getInstance();
        inst.drivers[name] = driver;
    };
    return Storage;
}());
exports.Storage = Storage;
//# sourceMappingURL=storage.js.map